Create HDF5 data file from Seurat object
Usage
CreateDataFile(
srt,
data_file,
name = NULL,
assays = "RNA",
layers = "data",
compression_level = 6,
overwrite = TRUE,
verbose = TRUE
)Arguments
- srt
A
Seuratobject.- data_file
Path to the output data file. If not provided, the file will be named
"data.hdf5"in the current directory.- name
Name of the dataset. If not provided, the name will default to the Seurat object's project name.
- assays
The assays to include in the data file.
- layers
The layers to include in the data file.
- compression_level
Compression level for the HDF5 dataset.
- overwrite
Whether to overwrite existing data in the data file.
- verbose
Whether to print the message. Default is
TRUE.