Skip to contents

Create Meta File in HDF5 format from Seurat object

Usage

CreateMetaFile(
  srt,
  meta_file,
  name = NULL,
  write_tools = FALSE,
  write_misc = FALSE,
  ignore_nlevel = 100,
  compression_level = 6,
  overwrite = TRUE,
  verbose = TRUE
)

Arguments

srt

A Seurat object.

meta_file

Path to the output meta file. If not provided, the file will be named "meta.hdf5" in the current directory.

name

Name of the dataset. If not provided, the name will default to the Seurat object's project name.

write_tools

Whether to write the tools information to the meta file.

write_misc

Whether to write the miscellaneous information to the meta file.

ignore_nlevel

The number of levels above which a metadata field will be ignored.

compression_level

The level of compression for the meta file.

overwrite

Whether to overwrite existing metadata and reductions in the meta file.

verbose

Whether to print the message. Default is TRUE.