Skip to contents

Visualize FitDevo developmental potential scores with scop dimensional and grouped summary plots.

Usage

FitDevoPlot(
  srt,
  reduction = NULL,
  group.by = NULL,
  score.name = "FitDevo_Score",
  relative.name = "FitDevo_Relative",
  combine = TRUE,
  nrow = NULL,
  ncol = NULL,
  byrow = TRUE,
  pt.size = NULL,
  pt.alpha = 1,
  palette = "Chinese",
  palcolor = NULL,
  theme_use = "theme_scop",
  theme_args = list(),
  ...
)

Arguments

srt

A Seurat object processed by RunFitDevo().

reduction

Reduction used by FeatureDimPlot() and CellDimPlot().

group.by

Optional metadata column used for phenotype and score distribution plots.

score.name

Metadata column containing the FitDevo score.

relative.name

Metadata column containing the FitDevo relative rank.

combine

Whether to combine plots with patchwork.

nrow, ncol, byrow

Layout arguments passed to patchwork::wrap_plots().

pt.size, pt.alpha

Point size and alpha.

palette, palcolor

Palette arguments for grouped plots.

theme_use, theme_args

Theme arguments passed to scop plot helpers.

...

Additional arguments passed to FeatureDimPlot() and CellDimPlot().

Value

A patchwork object or a named list of ggplot objects.

Examples

data(pancreas_sub)
pancreas_sub <- standard_scop(pancreas_sub)
#>  [2026-07-28 03:30:58] Start standard processing workflow...
#>  [2026-07-28 03:30:58] Checking a list of <Seurat>...
#> ! [2026-07-28 03:30:58] Data 1/1 of the `srt_list` is "unknown"
#>  [2026-07-28 03:30:58] Perform `NormalizeData()` with `normalization.method = 'LogNormalize'` on 1/1 of `srt_list`...
#>  [2026-07-28 03:30:58] Perform `FindVariableFeatures()` on 1/1 of `srt_list`...
#>  [2026-07-28 03:30:59] Use the separate HVF from `srt_list`
#>  [2026-07-28 03:30:59] Number of available HVF: 2000
#>  [2026-07-28 03:30:59] Finished check
#>  [2026-07-28 03:30:59] Perform `ScaleData()`
#>  [2026-07-28 03:30:59] Perform pca linear dimension reduction
#>  [2026-07-28 03:31:00] Use stored estimated dimensions 1:23 for Standardpca
#>  [2026-07-28 03:31:00] Perform `Seurat::FindClusters()` with `cluster_algorithm = 'louvain'` and `cluster_resolution = 0.6`
#>  [2026-07-28 03:31:00] Reorder clusters...
#>  [2026-07-28 03:31:01] Skip `log1p()` because `layer = data` is not "counts"
#>  [2026-07-28 03:31:01] Perform umap nonlinear dimension reduction
#>  [2026-07-28 03:31:06] Standard processing workflow completed
pancreas_sub <- RunFitDevo(pancreas_sub, verbose = FALSE)
FitDevoPlot(pancreas_sub)