List the public spatial analysis, visualization, framework bridge, and workflow entry points registered by scop. This function does not inspect optional packages unless `available` is `TRUE` or `FALSE`.
Usage
ListSpatialMethods(
task = NULL,
kind = NULL,
backend = NULL,
status = NULL,
available = NULL,
pattern = NULL
)