`standard_scop()` and `integration_scop()` were renamed to [RunStandardWorkflow()] and [RunIntegration()]. The compatibility entry points remain available with a warning in releases before 1.0.0 and will be removed in version 1.0.0.
`standard_scop()` and `integration_scop()` were renamed to [RunStandardWorkflow()] and [RunIntegration()]. The compatibility entry points remain available with a warning in releases before 1.0.0 and will be removed in version 1.0.0.