Skip to contents

Read a .loom file as an AnnData object

Usage

loom_to_adata(path, verbose = TRUE, ...)

Arguments

path

Path to a .loom file (passed to scanpy.read_loom()).

verbose

Whether to print the message. Default is TRUE.

...

Additional arguments passed to scanpy.read_loom().

Value

A Python anndata.AnnData object.

Details

This is a Python-backed wrapper and requires reticulate plus a Python environment with scanpy and loompy available. It is independent from loom_to_srt(), which reads loom files directly in R without initializing Python.

Examples

if (FALSE) { # \dontrun{
adata <- loom_to_adata("path/to/data.loom")
adata
} # }