Based on the human cell cycle genes, the cell cycle genes of the corresponding species were captured by homologous gene conversion.
Usage
CycGenePrefetch(
species = "Homo_sapiens",
Ensembl_version = NULL,
mirror = NULL,
max_tries = 5,
use_cached_gene = TRUE,
verbose = TRUE
)Arguments
- species
Latin names for animals, i.e.,
"Homo_sapiens","Mus_musculus"- Ensembl_version
An integer specifying the Ensembl version. Default is
NULL. IfNULL, the latest version will be used.- mirror
Specify an Ensembl mirror to connect to. The valid options here are
"www","uswest","useast","asia".- max_tries
The maximum number of attempts to connect with the BioMart service.
- use_cached_gene
Whether to use previously cached cell cycle gene conversion results for the species. Default is
TRUE.- verbose
Whether to print the message. Default is
TRUE.