Visualize ESTIMATE stromal, immune, combined ESTIMATE, and tumor-purity
scores from a RunESTIMATE() result.
Arguments
- object
Optional
RunESTIMATE()bundle,SummarizedExperiment, orSeuratobject containing ESTIMATE results.- score.data
Optional score matrix or data frame with samples in rows.
- group.by
Optional grouping column for grouped violin and box plots.
- group.data
Optional named vector or data frame containing sample groups.
- plot_type
Plot type.
- scores
ESTIMATE score columns to plot.
- add_stat
Whether to add group comparison labels to violin or box plots. Requires
ggpubr.- ...
Additional plotting arguments.