Skip to contents

Lists the gene annotation databases cached by PrepareDB and PrepareCCCDB in the R.cache root, optionally filtered by species and database name. Each row describes one cached database with its version and creation date.

Usage

ListDB(species = c("Homo_sapiens", "Mus_musculus"), db = NULL)

Arguments

species

Species. Can be "Homo_sapiens" or "Mus_musculus".

db

Database names (for example "GO_BP", "KEGG", "CellChat"), or a regular expression. If NULL, all databases are listed.

Value

A data frame with columns Database, Species, Version, and Date.

Examples

ListDB(species = "Homo_sapiens")
#> [1] Database Species  Version  Date    
#> <0 rows> (or 0-length row.names)
ListDB(species = c("Homo_sapiens", "Mus_musculus"))
#>   Database      Species                Version                       Date
#> 1     CSPA Mus_musculus           CSPA nterm:1 2026-08-30 04:23:52.866516
#> 2       DO Mus_musculus       9.0.0 nterm:6595 2026-08-30 04:26:22.186597
#> 3    GO_BP Mus_musculus     3.23.0 nterm:14957 2026-08-30 04:25:22.379975
#> 4    GO_CC Mus_musculus      3.23.0 nterm:2065 2026-08-30 04:25:23.744979
#> 5       MP Mus_musculus 2026-08-30 nterm:10917 2026-08-30 04:26:18.354453
#> 6       TF Mus_musculus    AnimalTFDB4 nterm:2 2026-08-30 04:00:31.526632
ListDB(species = "Mus_musculus", db = "GO_BP")
#>   Database      Species            Version                       Date
#> 1    GO_BP Mus_musculus 3.23.0 nterm:14957 2026-08-30 04:25:22.379975