Plot model improvements or view contributions from a result produced by [RunMistyR()] without rerunning the backend.
Usage
MistyRPlot(
object = NULL,
res = NULL,
type = c("improvements", "contributions"),
top_n = 20,
target = NULL
)Plot model improvements or view contributions from a result produced by [RunMistyR()] without rerunning the backend.
MistyRPlot(
object = NULL,
res = NULL,
type = c("improvements", "contributions"),
top_n = 20,
target = NULL
)