Attempt to recover raw counts from the normalized matrix
Arguments
- srt
A Seurat object.
- assay
Which assay to use. If
NULL, the default assay of the Seurat object will be used. When the object also containsChromatinAssay, the default assay and additionalChromatinAssaywill be preprocessed sequentially.- trans
The transformation function to applied when data is presumed to be log-normalized.
- min_count
Minimum UMI count of genes.
- tolerance
When recovering the raw counts, the nCount of each cell is theoretically calculated as an integer. However, due to decimal point preservation during normalization, the calculated nCount is usually a floating point number close to the integer. The tolerance is its difference from the integer. Default is
0.1- sf
Set the scaling factor manually.
- verbose
Whether to print the message. Default is
TRUE.
Examples
data(pancreas_sub)
pancreas_sub <- standard_scop(pancreas_sub)
raw_counts <- GetAssayData5(
pancreas_sub,
assay = "RNA",
layer = "counts"
)
# Normalized the data
pancreas_sub <- Seurat::NormalizeData(pancreas_sub)
# Now replace counts with the log-normalized data matrix
data <- GetAssayData5(
pancreas_sub,
assay = "RNA",
layer = "data"
)
new_pancreas_sub <- SeuratObject::SetAssayData(
object = pancreas_sub,
layer = "counts",
new.data = data,
assay = "RNA"
)
# Recover the counts and compare with the raw counts matrix
pancreas_sub <- RecoverCounts(new_pancreas_sub)
new_counts <- GetAssayData5(
pancreas_sub,
assay = "RNA",
layer = "counts"
)
identical(raw_counts, new_counts)