Skip to contents

Calculate common scATAC QC metrics and optionally filter cells by thresholds.

Usage

RunATACQC(
  srt,
  assay = NULL,
  tss.positions = NULL,
  blacklist = NULL,
  fast = TRUE,
  min_pct_reads_in_peaks = NULL,
  min_TSS_enrichment = NULL,
  max_nucleosome_signal = NULL,
  max_blacklist_ratio = NULL,
  verbose = TRUE
)

Arguments

srt

A Seurat object.

assay

Which assay to use. If NULL, the default assay of the Seurat object will be used. When the object also contains ChromatinAssay, the default assay and additional ChromatinAssay will be preprocessed sequentially.

tss.positions

TSS positions passed to Signac::TSSEnrichment.

blacklist

A GRanges blacklist used to compute blacklist_ratio.

fast

Whether to use the fast mode in Signac::TSSEnrichment.

min_pct_reads_in_peaks, min_TSS_enrichment, max_nucleosome_signal, max_blacklist_ratio

Optional thresholds used for filtering cells.

verbose

Whether to print the message. Default is TRUE.

Value

A Seurat object with QC metadata added.

Examples

# \donttest{
data("pbmcmultiome_sub", package = "scop")
pbmcmultiome_sub <- RunATACQC(
  pbmcmultiome_sub,
  assay = "peaks",
  fast = TRUE
)
#>  [2026-05-14 06:47:49] Calculating ATAC QC metrics...
#> ! [2026-05-14 06:47:49] Skip nucleosome signal: "No fragment files present in assay"
#> ! [2026-05-14 06:47:49] Skip FRiP calculation: no total fragment count column or local fragments available
#>  [2026-05-14 06:47:49] ATAC QC completed
# }