Run CellChat analysis
Arguments
- srt
A Seurat object.
- group.by
Name of one or more meta.data columns to group (color) cells by.
- species
The species of the data, either
"Homo_sapiens","Mus_musculus", or"zebrafish".- split.by
Name of a column in meta.data column to split plot by. Default is
NULL.- annotation_selected
A vector of cell annotations of interest for running the
CellChatanalysis. If not provided, all cell types will be considered.- group_column
Name of the metadata column in the
Seuratobject that defines conditions or groups.- group_cmp
A list of pairwise condition comparisons for differential
CellChatanalysis.- thresh
The threshold for computing centrality scores. Default is
0.05.- min.cells
the minmum number of expressed cells required for the genes that are considered for cell-cell communication analysis. Default is
10.- do.fast
Whether to use CellChat's fast Wilcoxon implementation backed by
presto. Set toTRUEonly whenprestois installed.- backend
Backend used for scop post-processing and unified CCC table aggregation. Upstream CellChat inference is unchanged.
- assay
Which assay to use. If
NULL, the default assay of theSeuratobject will be used.- layer
The layer to use for the expression data. Default is
"data".- verbose
Whether to print the message. Default is
TRUE.
Examples
data(pancreas_sub)
pancreas_sub <- standard_scop(pancreas_sub)
pancreas_sub <- RunCellChat(
pancreas_sub,
group.by = "CellType",
species = "Mus_musculus"
)
CCCNetworkPlot(
pancreas_sub,
method = "CellChat",
plot_type = "bipartite"
)
CCCHeatmap(
pancreas_sub,
method = "CellChat",
plot_type = "heatmap"
)
CCCStatPlot(
pancreas_sub,
method = "CellChat",
plot_type = "violin",
top_n = 50
)