Run dimension reduction
Usage
RunDimReduction(
srt,
prefix = "",
features = NULL,
assay = NULL,
layer = "data",
linear_reduction = NULL,
linear_reduction_dims = 50,
linear_reduction_params = list(),
force_linear_reduction = FALSE,
nonlinear_reduction = NULL,
nonlinear_reduction_dims = 2,
reduction_use = NULL,
reduction_dims = NULL,
graph_use = NULL,
neighbor_use = NULL,
nonlinear_reduction_params = list(),
force_nonlinear_reduction = TRUE,
verbose = TRUE,
seed = 11
)Arguments
- srt
A Seurat object.
- prefix
The prefix used to name the result.
- features
A character vector of features to use. Default is
NULL.- assay
Which assay to use. If
NULL, the default assay of the Seurat object will be used.- layer
Which layer to use. Default is
"counts".- linear_reduction
The linear dimensionality reduction method to use. Options are
"pca","svd","ica","nmf","mds", or"glmpca". Default is"pca".- linear_reduction_dims
Total number of dimensions to compute and store for
linear_reduction.- linear_reduction_params
Other parameters passed to the
linear_reductionmethod.- force_linear_reduction
Whether force to do linear dimension reduction.
- nonlinear_reduction
The nonlinear dimensionality reduction method to use. Options are
"umap","umap-naive","tsne","dm","phate","pacmap","trimap","largevis", or"fr". Default is"umap".- nonlinear_reduction_dims
Total number of dimensions to compute and store for
nonlinear_reduction.- reduction_use
Which dimensional reduction to use as input for
nonlinear_reduction.- reduction_dims
Which dimensions to use as input for
nonlinear_reduction, used only iffeaturesisNULL.- graph_use
Name of graph to use for the
nonlinear_reduction.- neighbor_use
Name of neighbor to use for the
nonlinear_reduction.- nonlinear_reduction_params
Other parameters passed to the
nonlinear_reductionmethod.- force_nonlinear_reduction
Whether force to do nonlinear dimension reduction.
- verbose
Whether to print the message. Default is
TRUE.- seed
Random seed for reproducibility. Default is
11.