Method-specific implementation used by RunProportionTest when
proportion_method = "propeller".
This implementation works on sample-level proportions using a propeller-style
transformed test and stores standardized outputs for plotting.
Usage
RunPropeller(
srt,
group.by,
split.by,
sample.by,
comparison = NULL,
n_bootstrap = 1000,
seed = 11,
verbose = TRUE
)Arguments
- srt
A Seurat object.
- group.by
Name of one or more meta.data columns to group (color) cells by.
- split.by
Metadata column that identifies the condition groups to compare. For sample-level methods, if
split.byis omitted andsample.byis provided,sample.byis treated as the condition column and virtual samples are created within each condition.- sample.by
Metadata column that identifies biological samples. For
"milo","sccoda", and"propeller", whensample.byis omitted or identical tosplit.by, virtual samples are created within eachsplit.bygroup for convenience.- comparison
Optional: specify comparisons to perform.
- n_bootstrap
Number of bootstrap iterations for confidence intervals.
- seed
Random seed.
- verbose
Whether to print the message. Default is
TRUE.
Value
A method result bundle used internally by RunProportionTest.