Run doublet-calling with scds
Arguments
- srt
A Seurat object.
- assay
The name of the assay to be used for doublet-calling. Default is
"RNA".- db_rate
The expected doublet rate. Default is calculated as
ncol(srt) / 1000 * 0.01.- method
The method to be used for doublet-calling. Options are
"hybrid","cxds", or"bcds".- data_type
Optional precomputed result from CheckDataType for the input assay. Primarily used internally to avoid repeated scans of the same count matrix across nested QC calls.
- ...
Additional arguments to be passed to
scds::cxds_bcds_hybrid().- verbose
Whether to print the message. Default is
TRUE.
Examples
data(pancreas_sub)
pancreas_sub <- standard_scop(pancreas_sub)
pancreas_sub <- db_scds(pancreas_sub, method = "hybrid")
CellDimPlot(
pancreas_sub,
reduction = "umap",
group.by = "db.scds_hybrid_class"
)
FeatureDimPlot(
pancreas_sub,
reduction = "umap",
features = "db.scds_hybrid_score"
)