Reorder idents by the gene expression
Usage
srt_reorder(
srt,
features = NULL,
reorder_by = NULL,
layer = "data",
assay = NULL,
log = TRUE,
distance_metric = "euclidean",
verbose = TRUE
)Arguments
- srt
A Seurat object.
- features
A character vector or a named list of features to plot. Features can be gene names in Assay or names of numeric columns in meta.data.
- reorder_by
Reorder groups instead of idents.
- layer
Which layer to use. Default is
data.- assay
Which assay to use. If
NULL, the default assay of the Seurat object will be used.- log
Whether log1p transformation needs to be applied. Default is
TRUE.- distance_metric
Metric to compute distance. Default is
"euclidean".- verbose
Whether to print the message. Default is
TRUE.
Examples
data(pancreas_sub)
pancreas_sub <- standard_scop(pancreas_sub)
#> ℹ [2026-03-20 09:54:10] Start standard scop workflow...
#> ℹ [2026-03-20 09:54:11] Checking a list of <Seurat>...
#> ! [2026-03-20 09:54:11] Data 1/1 of the `srt_list` is "unknown"
#> ℹ [2026-03-20 09:54:11] Perform `NormalizeData()` with `normalization.method = 'LogNormalize'` on 1/1 of `srt_list`...
#> ℹ [2026-03-20 09:54:14] Perform `Seurat::FindVariableFeatures()` on 1/1 of `srt_list`...
#> ℹ [2026-03-20 09:54:15] Use the separate HVF from `srt_list`
#> ℹ [2026-03-20 09:54:15] Number of available HVF: 2000
#> ℹ [2026-03-20 09:54:15] Finished check
#> ℹ [2026-03-20 09:54:15] Perform `Seurat::ScaleData()`
#> ℹ [2026-03-20 09:54:16] Perform pca linear dimension reduction
#> ℹ [2026-03-20 09:54:17] Perform `Seurat::FindClusters()` with `cluster_algorithm = 'louvain'` and `cluster_resolution = 0.6`
#> ℹ [2026-03-20 09:54:17] Reorder clusters...
#> ℹ [2026-03-20 09:54:17] Perform umap nonlinear dimension reduction
#> ℹ [2026-03-20 09:54:17] Perform umap nonlinear dimension reduction using Standardpca (1:50)
#> ℹ [2026-03-20 09:54:22] Perform umap nonlinear dimension reduction using Standardpca (1:50)
#> ✔ [2026-03-20 09:54:27] Run scop standard workflow completed
pancreas_sub <- srt_reorder(
pancreas_sub,
reorder_by = "SubCellType",
layer = "data"
)